# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, Union, Mapping
from typing_extensions import Self, override

import httpx

from . import _exceptions
from ._qs import Querystring
from ._types import (
    NOT_GIVEN,
    Omit,
    Timeout,
    NotGiven,
    Transport,
    ProxiesTypes,
    RequestOptions,
)
from ._utils import (
    is_given,
    get_async_library,
)
from ._version import __version__
from .resources import oauth, health, manifest_json, opensearch_xml
from ._streaming import Stream as Stream, AsyncStream as AsyncStream
from ._exceptions import APIStatusError, PyopenwebuiError
from ._base_client import (
    DEFAULT_MAX_RETRIES,
    SyncAPIClient,
    AsyncAPIClient,
)
from .resources.api import api
from .resources.ollama import ollama
from .resources.openai import openai

__all__ = [
    "Timeout",
    "Transport",
    "ProxiesTypes",
    "RequestOptions",
    "Pyopenwebui",
    "AsyncPyopenwebui",
    "Client",
    "AsyncClient",
]


class Pyopenwebui(SyncAPIClient):
    ollama: ollama.OllamaResource
    openai: openai.OpenAIResource
    api: api.APIResource
    oauth: oauth.OAuthResource
    manifest_json: manifest_json.ManifestJsonResource
    opensearch_xml: opensearch_xml.OpensearchXmlResource
    health: health.HealthResource
    with_raw_response: PyopenwebuiWithRawResponse
    with_streaming_response: PyopenwebuiWithStreamedResponse

    # client options
    bearer_token: str

    def __init__(
        self,
        *,
        bearer_token: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: Union[float, Timeout, None, NotGiven] = NOT_GIVEN,
        max_retries: int = DEFAULT_MAX_RETRIES,
        default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        # Configure a custom httpx client.
        # We provide a `DefaultHttpxClient` class that you can pass to retain the default values we use for `limits`, `timeout` & `follow_redirects`.
        # See the [httpx documentation](https://www.python-httpx.org/api/#client) for more details.
        http_client: httpx.Client | None = None,
        # Enable or disable schema validation for data returned by the API.
        # When enabled an error APIResponseValidationError is raised
        # if the API responds with invalid data for the expected schema.
        #
        # This parameter may be removed or changed in the future.
        # If you rely on this feature, please open a GitHub issue
        # outlining your use-case to help us decide if it should be
        # part of our public interface in the future.
        _strict_response_validation: bool = False,
    ) -> None:
        """Construct a new synchronous pyopenwebui client instance.

        This automatically infers the `bearer_token` argument from the `PYOPENWEBUI_BEARER_TOKEN` environment variable if it is not provided.
        """
        if bearer_token is None:
            bearer_token = os.environ.get("PYOPENWEBUI_BEARER_TOKEN")
        if bearer_token is None:
            raise PyopenwebuiError(
                "The bearer_token client option must be set either by passing bearer_token to the client or by setting the PYOPENWEBUI_BEARER_TOKEN environment variable"
            )
        self.bearer_token = bearer_token

        if base_url is None:
            base_url = os.environ.get("PYOPENWEBUI_BASE_URL")
        if base_url is None:
            base_url = f"/api/v1"

        super().__init__(
            version=__version__,
            base_url=base_url,
            max_retries=max_retries,
            timeout=timeout,
            http_client=http_client,
            custom_headers=default_headers,
            custom_query=default_query,
            _strict_response_validation=_strict_response_validation,
        )

        self.ollama = ollama.OllamaResource(self)
        self.openai = openai.OpenAIResource(self)
        self.api = api.APIResource(self)
        self.oauth = oauth.OAuthResource(self)
        self.manifest_json = manifest_json.ManifestJsonResource(self)
        self.opensearch_xml = opensearch_xml.OpensearchXmlResource(self)
        self.health = health.HealthResource(self)
        self.with_raw_response = PyopenwebuiWithRawResponse(self)
        self.with_streaming_response = PyopenwebuiWithStreamedResponse(self)

    @property
    @override
    def qs(self) -> Querystring:
        return Querystring(array_format="comma")

    @property
    @override
    def auth_headers(self) -> dict[str, str]:
        bearer_token = self.bearer_token
        return {"Authorization": f"Bearer {bearer_token}"}

    @property
    @override
    def default_headers(self) -> dict[str, str | Omit]:
        return {
            **super().default_headers,
            "X-Stainless-Async": "false",
            **self._custom_headers,
        }

    def copy(
        self,
        *,
        bearer_token: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = NOT_GIVEN,
        http_client: httpx.Client | None = None,
        max_retries: int | NotGiven = NOT_GIVEN,
        default_headers: Mapping[str, str] | None = None,
        set_default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        set_default_query: Mapping[str, object] | None = None,
        _extra_kwargs: Mapping[str, Any] = {},
    ) -> Self:
        """
        Create a new client instance re-using the same options given to the current client with optional overriding.
        """
        if default_headers is not None and set_default_headers is not None:
            raise ValueError("The `default_headers` and `set_default_headers` arguments are mutually exclusive")

        if default_query is not None and set_default_query is not None:
            raise ValueError("The `default_query` and `set_default_query` arguments are mutually exclusive")

        headers = self._custom_headers
        if default_headers is not None:
            headers = {**headers, **default_headers}
        elif set_default_headers is not None:
            headers = set_default_headers

        params = self._custom_query
        if default_query is not None:
            params = {**params, **default_query}
        elif set_default_query is not None:
            params = set_default_query

        http_client = http_client or self._client
        return self.__class__(
            bearer_token=bearer_token or self.bearer_token,
            base_url=base_url or self.base_url,
            timeout=self.timeout if isinstance(timeout, NotGiven) else timeout,
            http_client=http_client,
            max_retries=max_retries if is_given(max_retries) else self.max_retries,
            default_headers=headers,
            default_query=params,
            **_extra_kwargs,
        )

    # Alias for `copy` for nicer inline usage, e.g.
    # client.with_options(timeout=10).foo.create(...)
    with_options = copy

    @override
    def _make_status_error(
        self,
        err_msg: str,
        *,
        body: object,
        response: httpx.Response,
    ) -> APIStatusError:
        if response.status_code == 400:
            return _exceptions.BadRequestError(err_msg, response=response, body=body)

        if response.status_code == 401:
            return _exceptions.AuthenticationError(err_msg, response=response, body=body)

        if response.status_code == 403:
            return _exceptions.PermissionDeniedError(err_msg, response=response, body=body)

        if response.status_code == 404:
            return _exceptions.NotFoundError(err_msg, response=response, body=body)

        if response.status_code == 409:
            return _exceptions.ConflictError(err_msg, response=response, body=body)

        if response.status_code == 422:
            return _exceptions.UnprocessableEntityError(err_msg, response=response, body=body)

        if response.status_code == 429:
            return _exceptions.RateLimitError(err_msg, response=response, body=body)

        if response.status_code >= 500:
            return _exceptions.InternalServerError(err_msg, response=response, body=body)
        return APIStatusError(err_msg, response=response, body=body)


class AsyncPyopenwebui(AsyncAPIClient):
    ollama: ollama.AsyncOllamaResource
    openai: openai.AsyncOpenAIResource
    api: api.AsyncAPIResource
    oauth: oauth.AsyncOAuthResource
    manifest_json: manifest_json.AsyncManifestJsonResource
    opensearch_xml: opensearch_xml.AsyncOpensearchXmlResource
    health: health.AsyncHealthResource
    with_raw_response: AsyncPyopenwebuiWithRawResponse
    with_streaming_response: AsyncPyopenwebuiWithStreamedResponse

    # client options
    bearer_token: str

    def __init__(
        self,
        *,
        bearer_token: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: Union[float, Timeout, None, NotGiven] = NOT_GIVEN,
        max_retries: int = DEFAULT_MAX_RETRIES,
        default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        # Configure a custom httpx client.
        # We provide a `DefaultAsyncHttpxClient` class that you can pass to retain the default values we use for `limits`, `timeout` & `follow_redirects`.
        # See the [httpx documentation](https://www.python-httpx.org/api/#asyncclient) for more details.
        http_client: httpx.AsyncClient | None = None,
        # Enable or disable schema validation for data returned by the API.
        # When enabled an error APIResponseValidationError is raised
        # if the API responds with invalid data for the expected schema.
        #
        # This parameter may be removed or changed in the future.
        # If you rely on this feature, please open a GitHub issue
        # outlining your use-case to help us decide if it should be
        # part of our public interface in the future.
        _strict_response_validation: bool = False,
    ) -> None:
        """Construct a new async pyopenwebui client instance.

        This automatically infers the `bearer_token` argument from the `PYOPENWEBUI_BEARER_TOKEN` environment variable if it is not provided.
        """
        if bearer_token is None:
            bearer_token = os.environ.get("PYOPENWEBUI_BEARER_TOKEN")
        if bearer_token is None:
            raise PyopenwebuiError(
                "The bearer_token client option must be set either by passing bearer_token to the client or by setting the PYOPENWEBUI_BEARER_TOKEN environment variable"
            )
        self.bearer_token = bearer_token

        if base_url is None:
            base_url = os.environ.get("PYOPENWEBUI_BASE_URL")
        if base_url is None:
            base_url = f"/api/v1"

        super().__init__(
            version=__version__,
            base_url=base_url,
            max_retries=max_retries,
            timeout=timeout,
            http_client=http_client,
            custom_headers=default_headers,
            custom_query=default_query,
            _strict_response_validation=_strict_response_validation,
        )

        self.ollama = ollama.AsyncOllamaResource(self)
        self.openai = openai.AsyncOpenAIResource(self)
        self.api = api.AsyncAPIResource(self)
        self.oauth = oauth.AsyncOAuthResource(self)
        self.manifest_json = manifest_json.AsyncManifestJsonResource(self)
        self.opensearch_xml = opensearch_xml.AsyncOpensearchXmlResource(self)
        self.health = health.AsyncHealthResource(self)
        self.with_raw_response = AsyncPyopenwebuiWithRawResponse(self)
        self.with_streaming_response = AsyncPyopenwebuiWithStreamedResponse(self)

    @property
    @override
    def qs(self) -> Querystring:
        return Querystring(array_format="comma")

    @property
    @override
    def auth_headers(self) -> dict[str, str]:
        bearer_token = self.bearer_token
        return {"Authorization": f"Bearer {bearer_token}"}

    @property
    @override
    def default_headers(self) -> dict[str, str | Omit]:
        return {
            **super().default_headers,
            "X-Stainless-Async": f"async:{get_async_library()}",
            **self._custom_headers,
        }

    def copy(
        self,
        *,
        bearer_token: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = NOT_GIVEN,
        http_client: httpx.AsyncClient | None = None,
        max_retries: int | NotGiven = NOT_GIVEN,
        default_headers: Mapping[str, str] | None = None,
        set_default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        set_default_query: Mapping[str, object] | None = None,
        _extra_kwargs: Mapping[str, Any] = {},
    ) -> Self:
        """
        Create a new client instance re-using the same options given to the current client with optional overriding.
        """
        if default_headers is not None and set_default_headers is not None:
            raise ValueError("The `default_headers` and `set_default_headers` arguments are mutually exclusive")

        if default_query is not None and set_default_query is not None:
            raise ValueError("The `default_query` and `set_default_query` arguments are mutually exclusive")

        headers = self._custom_headers
        if default_headers is not None:
            headers = {**headers, **default_headers}
        elif set_default_headers is not None:
            headers = set_default_headers

        params = self._custom_query
        if default_query is not None:
            params = {**params, **default_query}
        elif set_default_query is not None:
            params = set_default_query

        http_client = http_client or self._client
        return self.__class__(
            bearer_token=bearer_token or self.bearer_token,
            base_url=base_url or self.base_url,
            timeout=self.timeout if isinstance(timeout, NotGiven) else timeout,
            http_client=http_client,
            max_retries=max_retries if is_given(max_retries) else self.max_retries,
            default_headers=headers,
            default_query=params,
            **_extra_kwargs,
        )

    # Alias for `copy` for nicer inline usage, e.g.
    # client.with_options(timeout=10).foo.create(...)
    with_options = copy

    @override
    def _make_status_error(
        self,
        err_msg: str,
        *,
        body: object,
        response: httpx.Response,
    ) -> APIStatusError:
        if response.status_code == 400:
            return _exceptions.BadRequestError(err_msg, response=response, body=body)

        if response.status_code == 401:
            return _exceptions.AuthenticationError(err_msg, response=response, body=body)

        if response.status_code == 403:
            return _exceptions.PermissionDeniedError(err_msg, response=response, body=body)

        if response.status_code == 404:
            return _exceptions.NotFoundError(err_msg, response=response, body=body)

        if response.status_code == 409:
            return _exceptions.ConflictError(err_msg, response=response, body=body)

        if response.status_code == 422:
            return _exceptions.UnprocessableEntityError(err_msg, response=response, body=body)

        if response.status_code == 429:
            return _exceptions.RateLimitError(err_msg, response=response, body=body)

        if response.status_code >= 500:
            return _exceptions.InternalServerError(err_msg, response=response, body=body)
        return APIStatusError(err_msg, response=response, body=body)


class PyopenwebuiWithRawResponse:
    def __init__(self, client: Pyopenwebui) -> None:
        self.ollama = ollama.OllamaResourceWithRawResponse(client.ollama)
        self.openai = openai.OpenAIResourceWithRawResponse(client.openai)
        self.api = api.APIResourceWithRawResponse(client.api)
        self.oauth = oauth.OAuthResourceWithRawResponse(client.oauth)
        self.manifest_json = manifest_json.ManifestJsonResourceWithRawResponse(client.manifest_json)
        self.opensearch_xml = opensearch_xml.OpensearchXmlResourceWithRawResponse(client.opensearch_xml)
        self.health = health.HealthResourceWithRawResponse(client.health)


class AsyncPyopenwebuiWithRawResponse:
    def __init__(self, client: AsyncPyopenwebui) -> None:
        self.ollama = ollama.AsyncOllamaResourceWithRawResponse(client.ollama)
        self.openai = openai.AsyncOpenAIResourceWithRawResponse(client.openai)
        self.api = api.AsyncAPIResourceWithRawResponse(client.api)
        self.oauth = oauth.AsyncOAuthResourceWithRawResponse(client.oauth)
        self.manifest_json = manifest_json.AsyncManifestJsonResourceWithRawResponse(client.manifest_json)
        self.opensearch_xml = opensearch_xml.AsyncOpensearchXmlResourceWithRawResponse(client.opensearch_xml)
        self.health = health.AsyncHealthResourceWithRawResponse(client.health)


class PyopenwebuiWithStreamedResponse:
    def __init__(self, client: Pyopenwebui) -> None:
        self.ollama = ollama.OllamaResourceWithStreamingResponse(client.ollama)
        self.openai = openai.OpenAIResourceWithStreamingResponse(client.openai)
        self.api = api.APIResourceWithStreamingResponse(client.api)
        self.oauth = oauth.OAuthResourceWithStreamingResponse(client.oauth)
        self.manifest_json = manifest_json.ManifestJsonResourceWithStreamingResponse(client.manifest_json)
        self.opensearch_xml = opensearch_xml.OpensearchXmlResourceWithStreamingResponse(client.opensearch_xml)
        self.health = health.HealthResourceWithStreamingResponse(client.health)


class AsyncPyopenwebuiWithStreamedResponse:
    def __init__(self, client: AsyncPyopenwebui) -> None:
        self.ollama = ollama.AsyncOllamaResourceWithStreamingResponse(client.ollama)
        self.openai = openai.AsyncOpenAIResourceWithStreamingResponse(client.openai)
        self.api = api.AsyncAPIResourceWithStreamingResponse(client.api)
        self.oauth = oauth.AsyncOAuthResourceWithStreamingResponse(client.oauth)
        self.manifest_json = manifest_json.AsyncManifestJsonResourceWithStreamingResponse(client.manifest_json)
        self.opensearch_xml = opensearch_xml.AsyncOpensearchXmlResourceWithStreamingResponse(client.opensearch_xml)
        self.health = health.AsyncHealthResourceWithStreamingResponse(client.health)


Client = Pyopenwebui

AsyncClient = AsyncPyopenwebui
