# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Optional

import httpx

from ...._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ...._utils import (
    maybe_transform,
    async_maybe_transform,
)
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.ollama.api import embedding_embeddings_params, embedding_embeddings_by_index_params

__all__ = ["EmbeddingsResource", "AsyncEmbeddingsResource"]


class EmbeddingsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> EmbeddingsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/aigc-libs/pyopenwebui-python#accessing-raw-response-data-eg-headers
        """
        return EmbeddingsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> EmbeddingsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/aigc-libs/pyopenwebui-python#with_streaming_response
        """
        return EmbeddingsResourceWithStreamingResponse(self)

    def embeddings(
        self,
        *,
        model: str,
        prompt: str,
        url_idx: Optional[int] | NotGiven = NOT_GIVEN,
        keep_alive: Union[int, str, None] | NotGiven = NOT_GIVEN,
        options: Optional[object] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Embeddings

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/ollama/api/embeddings",
            body=maybe_transform(
                {
                    "model": model,
                    "prompt": prompt,
                    "keep_alive": keep_alive,
                    "options": options,
                },
                embedding_embeddings_params.EmbeddingEmbeddingsParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"url_idx": url_idx}, embedding_embeddings_params.EmbeddingEmbeddingsParams),
            ),
            cast_to=object,
        )

    def embeddings_by_index(
        self,
        url_idx: int,
        *,
        model: str,
        prompt: str,
        keep_alive: Union[int, str, None] | NotGiven = NOT_GIVEN,
        options: Optional[object] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Embeddings

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            f"/ollama/api/embeddings/{url_idx}",
            body=maybe_transform(
                {
                    "model": model,
                    "prompt": prompt,
                    "keep_alive": keep_alive,
                    "options": options,
                },
                embedding_embeddings_by_index_params.EmbeddingEmbeddingsByIndexParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class AsyncEmbeddingsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncEmbeddingsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/aigc-libs/pyopenwebui-python#accessing-raw-response-data-eg-headers
        """
        return AsyncEmbeddingsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncEmbeddingsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/aigc-libs/pyopenwebui-python#with_streaming_response
        """
        return AsyncEmbeddingsResourceWithStreamingResponse(self)

    async def embeddings(
        self,
        *,
        model: str,
        prompt: str,
        url_idx: Optional[int] | NotGiven = NOT_GIVEN,
        keep_alive: Union[int, str, None] | NotGiven = NOT_GIVEN,
        options: Optional[object] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Embeddings

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/ollama/api/embeddings",
            body=await async_maybe_transform(
                {
                    "model": model,
                    "prompt": prompt,
                    "keep_alive": keep_alive,
                    "options": options,
                },
                embedding_embeddings_params.EmbeddingEmbeddingsParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"url_idx": url_idx}, embedding_embeddings_params.EmbeddingEmbeddingsParams
                ),
            ),
            cast_to=object,
        )

    async def embeddings_by_index(
        self,
        url_idx: int,
        *,
        model: str,
        prompt: str,
        keep_alive: Union[int, str, None] | NotGiven = NOT_GIVEN,
        options: Optional[object] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Embeddings

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            f"/ollama/api/embeddings/{url_idx}",
            body=await async_maybe_transform(
                {
                    "model": model,
                    "prompt": prompt,
                    "keep_alive": keep_alive,
                    "options": options,
                },
                embedding_embeddings_by_index_params.EmbeddingEmbeddingsByIndexParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class EmbeddingsResourceWithRawResponse:
    def __init__(self, embeddings: EmbeddingsResource) -> None:
        self._embeddings = embeddings

        self.embeddings = to_raw_response_wrapper(
            embeddings.embeddings,
        )
        self.embeddings_by_index = to_raw_response_wrapper(
            embeddings.embeddings_by_index,
        )


class AsyncEmbeddingsResourceWithRawResponse:
    def __init__(self, embeddings: AsyncEmbeddingsResource) -> None:
        self._embeddings = embeddings

        self.embeddings = async_to_raw_response_wrapper(
            embeddings.embeddings,
        )
        self.embeddings_by_index = async_to_raw_response_wrapper(
            embeddings.embeddings_by_index,
        )


class EmbeddingsResourceWithStreamingResponse:
    def __init__(self, embeddings: EmbeddingsResource) -> None:
        self._embeddings = embeddings

        self.embeddings = to_streamed_response_wrapper(
            embeddings.embeddings,
        )
        self.embeddings_by_index = to_streamed_response_wrapper(
            embeddings.embeddings_by_index,
        )


class AsyncEmbeddingsResourceWithStreamingResponse:
    def __init__(self, embeddings: AsyncEmbeddingsResource) -> None:
        self._embeddings = embeddings

        self.embeddings = async_to_streamed_response_wrapper(
            embeddings.embeddings,
        )
        self.embeddings_by_index = async_to_streamed_response_wrapper(
            embeddings.embeddings_by_index,
        )
